from ._unselected import Unselected
from plotly.graph_objs.splom import unselected
from ._stream import Stream
from ._selected import Selected
from plotly.graph_objs.splom import selected
from ._marker import Marker
from plotly.graph_objs.splom import marker
from ._hoverlabel import Hoverlabel
from plotly.graph_objs.splom import hoverlabel
from ._dimension import Dimension
from plotly.graph_objs.splom import dimension
from ._diagonal import Diagonal
